# encoding: utf-8
"""
created: August, 2019

author: P. R. Wiecha

Part of set of example scripts demonstrating `pyGDM2.EO` for directional 
scattering problems.

script "02": reload and plot results for plane wave antenna optimization
"""
import numpy as np
import matplotlib.pyplot as plt

from pyGDM2 import linear
from pyGDM2 import tools
from pyGDM2 import visu
from pyGDM2.EO.tools import get_best_candidate


## --- optimization file locations
load_file = 'eo_direct_gold_plane_wave_45deg.eo'

   
## --- load best candidate of a specific iteration (-1: last)
sim = get_best_candidate(load_file, iteration=-1, verbose=True)
tools.print_sim_info(sim, verbose=1)


## --- calculate farfield pattern up
tetalist, philist, I_sc, I_tot, I0 = linear.farfield(sim, field_index=0,
                                r=10000, tetamin=0, tetamax=np.pi/2., 
                                Nteta=18, Nphi=36)
## --- calculate farfield pattern down (into substrate)
tetalist_subst, philist_subst, I_sc_subst, I_tot_subst, I0_subst = linear.farfield(sim, field_index=0,
                                r=10000, tetamin=np.pi/2., tetamax=np.pi, 
                                Nteta=18, Nphi=36)


#%%
## --- plot
plt.figure(figsize=(12,3.5))

plt.subplot(231, aspect="equal")
plt.title("phase E_X")
NF_imagX = tools.get_field_as_list_by_fieldindex(sim, 0).T[ [0,1,2,3,4,5] ]
colorcode1 = np.angle(NF_imagX[3]) * 180./np.pi

plt.scatter(NF_imagX[0], NF_imagX[1], c=colorcode1, cmap='bwr', marker='s', s=10, linewidth=0)
plt.colorbar(label=r'phase of $E_x$ (deg)')

plt.subplot(234, aspect="equal")
plt.title("phase E_Y")
NF_imagX = tools.get_field_as_list_by_fieldindex(sim, 0).T[ [0,1,2,3,4,5] ]
colorcode1 = np.angle(NF_imagX[4]) * 180./np.pi

plt.scatter(NF_imagX[0], NF_imagX[1], c=colorcode1, cmap='bwr', marker='s', s=10, linewidth=0)
plt.colorbar(label=r'phase of $E_y$ (deg)')


plt.subplot(132, polar=True)
plt.title("farfield - upper")
visu.farfield_pattern_2D(tetalist, philist, I_sc, show=False)
plt.colorbar()

plt.subplot(133, polar=True)
plt.title("farfield - lower (inside substrate)")
visu.farfield_pattern_2D(np.pi-tetalist_subst, philist_subst, I_sc_subst, show=False)
plt.colorbar()

plt.tight_layout()
plt.show()

