# encoding: utf-8
"""
created: August, 2019

author: P. R. Wiecha

Part of set of example scripts demonstrating `pyGDM2.EO` for directional 
scattering problems.

script "05": reload and plot results for dipole emitter antenna optimization
"""
import numpy as np
import matplotlib.pyplot as plt

from pyGDM2 import linear
from pyGDM2 import tools
from pyGDM2 import visu
from pyGDM2.EO.tools import get_best_candidate


## --- optimization file locations
file_unsym = 'eo_direct_gold_Xdipole_unsymmetric.eo'
file_sym = 'eo_direct_gold_Xdipole_symmetric.eo'

   
## --- load best candidate of a specific iteration (-1: last)
sim = get_best_candidate(file_unsym, iteration=-1, verbose=True)
sim_sym = get_best_candidate(file_sym, iteration=-1, verbose=True)
tools.print_sim_info(sim, verbose=1)


## --- calculate farfield pattern up
tetalist, philist, I_sc, I_tot, I0 = linear.farfield(sim, field_index=0,
                                r=10000, tetamin=0, tetamax=np.pi/2., 
                                Nteta=18, Nphi=36)
tetalist, philist, I_sc_sym, I_tot_sym, I0_sym = linear.farfield(sim_sym, field_index=0,
                                r=10000, tetamin=0, tetamax=np.pi/2., 
                                Nteta=18, Nphi=36)


#%%
## --- plot
plt.figure(figsize=(12,3.5))

# =============================================================================
# plot non-symmetric optimization
# =============================================================================
plt.subplot(241, aspect="equal")
plt.title("amplitude E_Y")
NF_imagX = tools.get_field_as_list_by_fieldindex(sim, 0).T[ [0,1,2,3,4,5] ]
colorcode1 = NF_imagX[3].real
plt.scatter(NF_imagX[0], NF_imagX[1], c=colorcode1, cmap='bwr', marker='s', s=10, linewidth=0)
plt.colorbar(label=r'phase of $E_x$ (deg)')

plt.subplot(245, aspect="equal")
plt.title("phase E_Y")
NF_imagX = tools.get_field_as_list_by_fieldindex(sim, 0).T[ [0,1,2,3,4,5] ]
colorcode1 = np.angle(NF_imagX[4]) * 180./np.pi
plt.scatter(NF_imagX[0], NF_imagX[1], c=colorcode1, cmap='bwr', marker='s', s=10, linewidth=0)
plt.colorbar(label=r'phase of $E_y$ (deg)')

plt.subplot(142, polar=True)
plt.title("unsymmetric optimization")
visu.farfield_pattern_2D(tetalist, philist, I_tot, show=False)
plt.colorbar()


# =============================================================================
# plot symmetric optimization
# =============================================================================
plt.subplot(243, aspect="equal")
plt.title("symmetric - amplitude E_Y")
NF_imagX = tools.get_field_as_list_by_fieldindex(sim_sym, 0).T[ [0,1,2,3,4,5] ]
colorcode1 = NF_imagX[3].real
plt.scatter(NF_imagX[0], NF_imagX[1], c=colorcode1, cmap='bwr', marker='s', s=10, linewidth=0)
plt.colorbar(label=r'phase of $E_x$ (deg)')

plt.subplot(247, aspect="equal")
plt.title("symmetric - phase E_Y")
NF_imagX = tools.get_field_as_list_by_fieldindex(sim_sym, 0).T[ [0,1,2,3,4,5] ]
colorcode1 = np.angle(NF_imagX[4]) * 180./np.pi
plt.scatter(NF_imagX[0], NF_imagX[1], c=colorcode1, cmap='bwr', marker='s', s=10, linewidth=0)
plt.colorbar(label=r'phase of $E_y$ (deg)')


plt.subplot(144, polar=True)
plt.title("symmetric optimization")
visu.farfield_pattern_2D(tetalist, philist, I_tot_sym, show=False)
plt.colorbar()


plt.tight_layout()
plt.show()

